pub struct LineColumn {
pub line: usize,
pub column: usize,
}Available on crate feature
span-locations only.Expand description
A line-column pair representing the start or end of a Span.
This type is semver exempt and not exposed by default.
Fields
line: usizeThe 1-indexed line in the source file on which the span starts or ends (inclusive).
column: usizeThe 0-indexed column (in UTF-8 characters) in the source file on which the span starts or ends (inclusive).